---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

**Prerequisites**
* [ ] Have you tested the operation in the API directly?
* [ ] Do you have the latest Ansible collection version?

**Describe the bug**
A clear and concise description of what the bug is.

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
Please provide an screenshot of the successful API call with cuRL, Postman, etc.

**Environment (please complete the following information):**
* Cisco DNA Center Version and patch: 
* Ansible Version:
* Collection version:
* OS Version: 

**Additional context**
Add any other context about the problem here.
